**********************************************************************************************
***Computing the marginal revenue effect of the 1975 EITC reform for single parents***********
**********************************************************************************************

quietly {
***Formula for Gateaux differential for tax revenue in direction h: Proposition 3, equation (7)*
**********************************************************************************************
***1975 EITC reform: marginal taxes reduced for y in (0,4000), increased on y in (4000,8000)**
***Formula for computing Gateaux differential in direction of 1975 EITC reform: equation (12)***
**********************************************************************************************

*Load data 
use "${data}R1974-sp.dta", clear

*Compute integral below revenue function
integ R_BM y, trapezoid gen(intRsp)
label var intRsp "Integral over R"

*Evaluate integral for interval (0,4000)
sum intRsp if y==4000
local Z1: di %9.3f r(mean)

*Evaluate integral for interval (4000,8000)
sum intRsp if y==8000
local Z2: di %9.3f r(mean) - `Z1'

*Calculate marginal revenue gain of EITC reform
local Z: di %9.3f -`Z1' + `Z2'
}

* Display marginal revenue gain of EITC reform for single parents
*(as reported in Table S.5 in Supplemental Material for California)**
di `Z'

